NanoPy Oracle

Oracle Online
Blockchain: NanoPy
Model: Loading...
Wallet: Not Connected
[W]

## Wallet Connection

Connect your MetaMask wallet to sign oracle queries on-chain. Your private key never leaves your wallet.

Connected Address: -
Balance: -
[>]

## Query Oracle

Select Model
What is Ethereum? ETH prediction Oracles Smart contracts
[R]

## Response

Oracle Response
Response will appear here...
Model: -
Tokens: -
Time: -
Confidence: -
TX: -
[H]

## Query History

[No History]

No queries yet. Start by asking the oracle something!